pub type StringFmt = TypedFmtWrite<String>;Expand description
A pre-configured factory for logging directly to a fmt String.
Aliased Type
pub struct StringFmt { /* private fields */ }pub type StringFmt = TypedFmtWrite<String>;A pre-configured factory for logging directly to a fmt String.
pub struct StringFmt { /* private fields */ }